import { EllipsisOutlined, PlusOutlined } from '@ant-design/icons';
import { ProTable } from '@ant-design/pro-components';
import { Button, Dropdown, Space, Tag, message } from 'antd';
import { useRef, useState } from 'react';
import { assemblyRequest } from '../../utils/Assembly';
import { useSelector, useDispatch } from 'react-redux'
import { historyRecordSearch } from '../../redux/historyRecord_reducer';
import { getHistoryRecord1 } from '../../utils/Api/Ticai';
const columns = [
  {
    title: '期号',
    dataIndex: 'issue',
  },
  {
    title: '开奖日期',
    key: 'showTime',
    dataIndex: 'openTime',
    valueType: 'date',
    sorter: true,
    defaultSortOrder: 'descend',
    hideInSearch: true,
  },
  {
    disable: true,
    title: '前区',
    dataIndex: 'frontWinningNum',
    search: false,
  },
  {
    disable: true,
    title: '后区',
    dataIndex: 'backWinningNum',
    search: false,
  },
  {
    disable: true,
    title: '原始前区',
    dataIndex: 'seqFrontWinningNum',
    search: false,

  },
  {
    disable: true,
    title: '原始后区',
    dataIndex: 'seqBackWinningNum',
    search: false,
  }
];
// 数据存入redux中，同步成功后更新redux中数据，默认增加条数和内容。
const HistoryReocrd = () => {
  const actionRef = useRef();
  const [pageSize, setPageSize] = useState(5);
  // const historyRecordData = useSelector(state => state.historyRecord.data)
  // const dispatch = useDispatch()
  // console.log("useSelector(state => state.history.data)", historyRecordData)
  // if (historyRecordData && historyRecordData.length > 0) {
  //   // actionRef.current.reload()
  // }
  return (
    <ProTable
      columns={columns}
      actionRef={actionRef}
      cardBordered
      request={async (params, sort, filter) => {
        const data = assemblyRequest(sort, filter, params)
        return getHistoryRecord1(data).then((response) => {
          console.log('respond', response)
          response = response.data
          // response 响应体数据
          if (response.status.code === 200) {
            // dispatch(historyRecordSearch(response.data.content))
            return {
              data: response.data.content,
              // success 请返回 true，
              // 不然 table 会停止解析数据，即使有数据
              success: true,
              // 不传会使用 data 的长度，如果是分页一定要传
              total: response.data.totalElements,
            }
          } else {
            message.error(response.status.message)
          }
        }).catch( (error)=> {
          console.log(error);
        });
      }
      }
      editable={{
        type: 'multiple',
      }}
      // columnsState={{
      //   persistenceKey: 'pro-table-singe-demos',
      //   persistenceType: 'localStorage',
      //   onChange(value) {
      //     console.log('value123: ', value);
      //   },
      // }}
      rowKey="id"
      search={{
        labelWidth: 'auto',
      }}
      options={{
        setting: {
          listsHeight: 400,
        },
      }}
      form={{
        // 由于配置了 transform，提交的参与与定义的不同这里需要转化一下
        syncToUrl: (values, type) => {
          if (type === 'get') {
            return {
              ...values,
              created_at: [values.startTime, values.endTime],
            };
          }
          return values;
        },
      }}
      pagination={{
        pageSize,
        onChange: (page) => setPageSize(page.pageSize),
      }}
      dateFormatter="string"
      headerTitle="历史开奖"
      toolBarRender={() => [
        <Dropdown
          key="menu"
          menu={{
            items: [
              {
                label: '1st item',
                key: '3',
              },
              {
                label: '2nd item',
                key: '2',
              },
              {
                label: '3rd item',
                key: '1',
              },
            ],
          }}
        >
          <Button>
            <EllipsisOutlined />
          </Button>
        </Dropdown>,
      ]}
    />
  )
}

export default HistoryReocrd