import ExampleTheme from "./themes/ExampleTheme";
import {LexicalComposer} from "@lexical/react/LexicalComposer";
import {RichTextPlugin} from "@lexical/react/LexicalRichTextPlugin";
import {ContentEditable} from "@lexical/react/LexicalContentEditable";
import {HistoryPlugin} from "@lexical/react/LexicalHistoryPlugin";
import {AutoFocusPlugin} from "@lexical/react/LexicalAutoFocusPlugin";
import LexicalErrorBoundary from "@lexical/react/LexicalErrorBoundary";
import TreeViewPlugin from "./plugins/TreeViewPlugin";
import ToolbarPlugin from "./plugins/ToolbarPlugin";
import {HeadingNode, QuoteNode} from "@lexical/rich-text";
import {TableCellNode, TableNode, TableRowNode} from "@lexical/table";
import {ListItemNode, ListNode} from "@lexical/list";
import {CodeHighlightNode, CodeNode} from "@lexical/code";
import {AutoLinkNode, LinkNode} from "@lexical/link";
import {MarkdownShortcutPlugin} from "@lexical/react/LexicalMarkdownShortcutPlugin";
import {TRANSFORMERS} from "@lexical/markdown";
import "./index.less"
import {useEffect, useId, useState} from 'react';
import {useLexicalComposerContext} from '@lexical/react/LexicalComposerContext';
import {importFile, overWriteFile, saveFileWithName} from "../../../utils/File"
import {CLEAR_HISTORY_COMMAND} from "lexical";
import {store} from "../../../redux/store";
import {SAVE} from "../../../utils/HotkeyConst";
import md5 from "md5"
import {isEmpty} from "../../../utils/ObjectUtils";

function Placeholder() {
    return <div className="editor-placeholder">Enter some rich text...</div>;
}

const editorConfig = {
    // The editor theme
    theme: ExampleTheme,
    // Handling of errors during update
    onError(error) {
        throw error;
    },
    // Any custom nodes go here
    nodes: [
        HeadingNode,
        ListNode,
        ListItemNode,
        QuoteNode,
        CodeNode,
        CodeHighlightNode,
        TableNode,
        TableCellNode,
        TableRowNode,
        AutoLinkNode,
        LinkNode
    ]
};

function OnChangePlugin({onChange}) {
    const [editor] = useLexicalComposerContext();
    console.log('editor', editor)
    useEffect(() => {
        return editor.registerUpdateListener(({editorState}) => {
            onChange(editorState);
        });
    }, [editor, onChange]);
}

function ImportFilePlugin(props) {
    const [editor] = useLexicalComposerContext();
    useEffect(() => {
        if (props.filePath){
            importFile(props.filePath).then(value => {
                const editorState = editor.parseEditorState(
                    JSON.stringify(JSON.parse(value.toString()).editorState)
                );
                editor.setEditorState(editorState);
                editor.dispatchCommand(CLEAR_HISTORY_COMMAND, undefined);
            }).catch(error =>
                console.error(error)
            )
        }
    }, [])
}


// 从字符串化 JSON 设置编辑器状态
// const editorState = editor.parseEditorState(editorStateJSONString);
// editor.setEditorState(editorState);

export default function Hlexical(props) {
    console.log("this.props.filePath:", props.filePath)
    const [editorState, setEditorState] = useState("");
    const [lastId ,setLastId]= useState("");
    function onChange(editorState) {
        // Call toJSON on the EditorState object, which produces a serialization safe string
        const editorStateJSON = editorState.toJSON();
        console.log('editorStateJSON', editorStateJSON)
        // However, we still have a JavaScript object, so we need to convert it to an actual string with JSON.stringify
        setEditorState(JSON.stringify(editorStateJSON));
    }

    function SaveFilePlugin(props) {
        useEffect(()=>{
            let unsubscribe = store.subscribe(() => {
                let filePath =props.filePath;
                console.log("触发保存filePath:",filePath)
                if (isEmpty(props.editorState)) {
                    return
                }
                // 如果文件地址为空需要用户选择目录并设置文件。
                if (!filePath){
                    let saveDialogReturnValuePromise = saveFileWithName();
                    console.log("saveDialogReturnValuePromise",saveDialogReturnValuePromise)
                    saveDialogReturnValuePromise.then(result=>{
                        if (!result.canceled){
                            const editorStateSave = {"editorState": JSON.parse(props.editorState)};
                            let resultSave = JSON.stringify(editorStateSave);
                            overWriteFile(result.filePath, resultSave)
                            // 修改当前文件名

                        }
                    })
                    return
                }

                const editorStateSave = {"editorState": JSON.parse(props.editorState)};
                let resultSave = JSON.stringify(editorStateSave);
                console.log("lastId", lastId)
                if ((lastId === "" || lastId !== store.getState().pushHotkeys.id) && store.getState().pushHotkeys.data === SAVE) {
                    setLastId(store.getState().pushHotkeys.id);
                    importFile(filePath).then(value => {
                        let save = md5(resultSave) !== md5(JSON.stringify(JSON.parse(value.toString())));
                        if (save) {
                            console.log("保存重写")
                            overWriteFile(filePath, resultSave)
                        }
                    }).catch(error =>
                        console.error(error)
                    )
                }
            });
            console.log("return unsubscribe();")
            return ()=>unsubscribe();
        },[props])

    }

    return (
        <LexicalComposer initialConfig={editorConfig}>
            <div className="editor-container">
                {/* 富文本插件 */}
                <ToolbarPlugin/>
                <div className="editor-inner">
                    <RichTextPlugin
                        contentEditable={<ContentEditable className="editor-input"/>}
                        placeholder={<Placeholder/>}
                        ErrorBoundary={LexicalErrorBoundary}
                    />
                    <HistoryPlugin/>
                    {/*黑窗口动态记录当前操作*/}
                    <TreeViewPlugin/>
                    <AutoFocusPlugin/>
                    {/*<CodeHighlightPlugin />*/}
                    {/*<ListPlugin />*/}
                    {/*<LinkPlugin />*/}
                    {/*<AutoLinkPlugin />*/}
                    {/*<ListMaxIndentLevelPlugin maxDepth={7} />*/}
                    <MarkdownShortcutPlugin transformers={TRANSFORMERS}/>
                    <OnChangePlugin onChange={onChange}/>
                    <ImportFilePlugin filePath={props.filePath}/>
                    <SaveFilePlugin filePath={props.filePath} editorState={editorState}/>
                    {/*<ActionPlugin/>*/}
                </div>
            </div>
        </LexicalComposer>
    );
}
